@@ -12,6 +12,9 @@ class IConfigurationService(Interface):
         on the cfgparse module.
     """
 
+    def __init__(watch=False, start_notification=False):
+        """ Initialize the configuration """
+
     def registerModel(filename):
         """ Register a configuration model with the service """
 
@@ -35,6 +38,8 @@ class IConfigurationService(Interface):
     def getConfigurationForDomain(domain):
         """ Return all configuration items as dict for a given domain"""
 
+    def start():
+        """ Start notification thread """
     def shutdown():
         """ Perform actions upon system shutdown """
 
