@@ -16,16 +16,19 @@ import zope.component
 from zope.configuration import xmlconfig
 from zope.component.testing import PlacelessSetup
 
+from pkg_resources import resource_filename, get_provider
+
 class DirectivesTest(PlacelessSetup, unittest.TestCase):
 
     def setUp(self):
         super(DirectivesTest, self).setUp()
+        provider = get_provider('haufe.hrs.configuration')
         os.environ['TESTING'] = '1'
+        os.environ['PACKAGE_ROOT'] = provider.egg_root
         gsm = zope.component.getGlobalSiteManager()
-        here = os.path.dirname(__file__)
-        zcml = file(os.path.join(here, "example.zcml")).read()
+        zcml = file(resource_filename('haufe.hrs.configuration', "tests/example.zcml")).read()
         self.context = xmlconfig.string(zcml)
-        super(DirectivesTest, self).tearDown()
+        super(DirectivesTest, self).setUp()
 
     def tearDown(self):
         super(DirectivesTest, self).tearDown()
